@@ -1,20 +1,23 @@
-import click
 import json
 import sys
 import time
 from datetime import datetime
+
+import click
 from dateutil.parser import parse
-from sdccli.printer import print_list, print_item
-from sdccli.time import duration_to_seconds
-from sdccli.cli.policy.rule import rule
-from sdccli.cli.policy.falco_list import falco_list
-from sdccli.cli.policy.falco_macro import falco_macro
 from prettytable import PrettyTable, PLAIN_COLUMNS
 
+import sdccli.usecases.policy.events as use_case
+from sdccli.cli.policy.falco_list import falco_list
+from sdccli.cli.policy.falco_macro import falco_macro
+from sdccli.cli.policy.rule import rule
+from sdccli.printer import print_list, print_item
+from sdccli.time import duration_to_seconds
 
 _item_keys_v1 = ["id", "name", "description", "falcoConfiguration", "actions", "scope", "notificationChannelIds"]
 _list_keys_v1 = ["id", "name", "severity", "isBuiltin", "notificationChannelIds"]
-_item_keys = ["id", "name", "description", "severity", "enabled", "scope", "ruleNames", "actions", "notificationChannelIds"]
+_item_keys = ["id", "name", "description", "severity", "enabled", "scope", "ruleNames", "actions",
+              "notificationChannelIds"]
 _list_keys = ["id", "name", "severity", "enabled"]
 
 
@@ -31,11 +34,13 @@ policy.add_command(falco_macro)
 @policy.command(name='add', short_help="Add a policy")
 @click.argument('name', nargs=1)
 @click.argument('description', nargs=1)
-@click.option('--rule', nargs=1, multiple=True, help="Rule name. It must be name instead of id, as the rules list view is by name, to account for multiple rules having the same name.")
+@click.option('--rule', nargs=1, multiple=True,
+              help="Rule name. It must be name instead of id, as the rules list view is by name, to account for multiple rules having the same name.")
 @click.option('--action', nargs=1, multiple=True, help="It can be a stop, pause and/or capture action")
 @click.option('--scope', nargs=1,
               help="Where the policy is being applied- Container, Host etc.. (example: 'container.image.repository = sysdig/agent')")
-@click.option('--severity', nargs=1, default=0, type=click.INT, help="How severe is this policy when violated. Range from 0 to 7 included.")
+@click.option('--severity', nargs=1, default=0, type=click.INT,
+              help="How severe is this policy when violated. Range from 0 to 7 included.")
 @click.option('--notenabled', is_flag=True, help=" If the policy should not be considered")
 @click.option('--notification', nargs=1, multiple=True, help="Notification channel id to subscribe to the policy.")
 @click.pass_obj
@@ -102,17 +107,59 @@ def add_json(cnf, policyfile):
         sys.exit(1)
 
 
-@policy.command(name='events', short_help="Get policy events")
+@policy.command(name="events", short_help="Get policy events")
+@click.option('--duration', nargs=1, help="Duration to display the events from. The minimum is 10 minutes. "
+                                          "(ex: 30M, 1H, 3D, 2W). Default: 3D.")
+@click.option('--scope', nargs=1, help="this is a Sysdig Monitor-like filter (e.g 'kubernetes.cluster.name in "
+                                       "(\"prod\", \"dev\")'). When provided, events are filtered by their scope, so "
+                                       "only a subset will be returned (e.g. 'container.image.repo=\"ubuntu\"' will "
+                                       "provide only events that have happened on an ubuntu container).")
+@click.option('--severity', nargs=1, help="Filter by severity. Valid ones are: 'high', 'med', 'low', 'info'. "
+                                          "Multiple ones can be specified if separated by commas. (e.g. 'med,low,info')")
+@click.option('--type', nargs=1, help="Filter by event originator. Valid ones are: 'scanning', 'policy'. "
+                                      "Multiple ones can be specified if separated by commas. (e.g. 'scanning,policy')")
+@click.option('--search', nargs=1, help="Search by event title or label")
+@click.option('--limit', nargs=1, type=click.INT, help="Limit the amount of events retrieved. Default: 50")
+@click.argument('event-id', nargs=1, required=False)
+@click.pass_obj
+def events(cnf, event_id, duration, scope, severity, type, search, limit):
+    try:
+        if event_id:
+            event = use_case.retrieve_policy_event_by_id(cnf.sdsecure, event_id)
+            cnf.formatter.format(event, "policyEventV1")
+            return
+
+
+        events = use_case.retrieve_all_policy_events(cnf.sdsecure, duration, scope, severity, type, search, limit)
+        cnf.formatter.format(events, "policyEventV1List")
+    except Exception as ex:
+        print(f"Error: {str(ex)}")
+        sys.exit(1)
+
+
+@policy.command(name='events_old', short_help="Get policy events (Use only on old onprem installations)")
 @click.argument('event-id', nargs=1, required=False)
 @click.option('--duration', nargs=1, help="Duration to display the events from. (ex: 30M, 1H, 3D, 2W)")
 @click.option('--start', nargs=1, help="Start of the time range.")
 @click.option('--end', nargs=1, help="End of the time range.")
-@click.option('--sampling', nargs=1, type=click.INT, default=60000000, help="sample all policy events using sampling interval.")
-@click.option('--aggregate', nargs=1, multiple=True, default=['ruleType'], help="Specifies how to aggregate events (sampling does not need to be specified, because when it's present it automatically means events will be aggregated). This field can either be a scope metric or a policyEvent field but (currently) not a mix of the two. When policy events fields are specified, only these can be used: severity, agentId, containerId, policyId, ruleType.")
-@click.option('--scope', nargs=1, help="this is a SysdigMonitor-like filter (e.g 'container.image=ubuntu'). When provided, events are filtered by their scope, so only a subset will be returned (e.g. 'container.image=ubuntu' will provide only events that have happened on an ubuntu container).")
-@click.option('--event-filter', nargs=1, help="this is a SysdigMonitor-like filter (e.g. policyEvent.policyId=3). When provided, events are filtered by some of their properties. Currently the supported set of filters is policyEvent.all(which can be used just with matches, policyEvent.policyId, policyEvent.id, policyEvent.severity, policyEvent.ruleTye, policyEvent.ruleSubtype.")
+@click.option('--sampling', nargs=1, type=click.INT, default=60000000,
+              help="sample all policy events using sampling interval.")
+@click.option('--aggregate', nargs=1, multiple=True, default=['ruleType'],
+              help="Specifies how to aggregate events (sampling does not need to be specified, because when it's "
+                   "present it automatically means events will be aggregated). This field can either be a scope "
+                   "metric or a policyEvent field but (currently) not a mix of the two. When policy events fields "
+                   "are specified, only these can be used: severity, agentId, containerId, policyId, ruleType.")
+@click.option('--scope', nargs=1,
+              help="this is a SysdigMonitor-like filter (e.g 'container.image=ubuntu'). When provided, events are "
+                   "filtered by their scope, so only a subset will be returned (e.g. 'container.image=ubuntu' will "
+                   "provide only events that have happened on an ubuntu container).")
+@click.option('--event-filter', nargs=1,
+              help="this is a SysdigMonitor-like filter (e.g. policyEvent.policyId=3). When provided, events are "
+                   "filtered by some of their properties. Currently the supported set of filters is "
+                   "policyEvent.all(which can be used just with matches, policyEvent.policyId, policyEvent.id, "
+                   "policyEvent.severity, policyEvent.ruleTye, policyEvent.ruleSubtype.")
 @click.pass_obj
-def events(cnf, event_id, duration, start, end, sampling, aggregate, scope, event_filter):
+def events_old(cnf, event_id, duration, start, end, sampling, aggregate, scope, event_filter):
     """
     EVENT-ID: id of an event to display, if not provided a list of events will be displayed
     """
@@ -128,9 +175,9 @@ def events(cnf, event_id, duration, start, end, sampling, aggregate, scope, even
             return
 
         if event_id:
-            ok, res = cnf.sdsecure.get_policy_events_id_duration(event_id, duration_sec, **kwargs)
+            ok, res = cnf.policy_events_client_old.get_policy_events_id_duration(event_id, duration_sec, **kwargs)
         else:
-            ok, res = cnf.sdsecure.get_policy_events_duration(duration_sec, **kwargs)
+            ok, res = cnf.policy_events_client_old.get_policy_events_duration(duration_sec, **kwargs)
 
     else:
         if end:
@@ -143,9 +190,9 @@ def events(cnf, event_id, duration, start, end, sampling, aggregate, scope, even
             start_time = end_time - (60 * 60)  # 1 hour
 
         if event_id:
-            ok, res = cnf.sdsecure.get_policy_events_id_range(event_id, start_time, end_time, **kwargs)
+            ok, res = cnf.policy_events_client_old.get_policy_events_id_range(event_id, start_time, end_time, **kwargs)
         else:
-            ok, res = cnf.sdsecure.get_policy_events_range(start_time, end_time, **kwargs)
+            ok, res = cnf.policy_events_client_old.get_policy_events_range(start_time, end_time, **kwargs)
 
     if cnf.json:
         print(json.dumps(res, indent=4))
@@ -188,10 +235,12 @@ def list(cnf):
 @click.option('--name', nargs=1, help="A short name for the policy")
 @click.option('--description', nargs=1, help="Description of policy")
 @click.option('--rule', nargs=1, multiple=True, help="Rule name. It will replace the rules defined in the policy")
-@click.option('--action', nargs=1, multiple=True, help="It can be a stop, pause and/or capture action. It will replace the actions defined in the policy")
+@click.option('--action', nargs=1, multiple=True,
+              help="It can be a stop, pause and/or capture action. It will replace the actions defined in the policy")
 @click.option('--scope', nargs=1,
               help="Where the policy is being applied- Container, Host etc.. (example: 'container.image.repository = sysdig/agent')")
-@click.option('--severity', nargs=1, type=click.INT, help="How severe is this policy when violated. Range from 0 to 7 included.")
+@click.option('--severity', nargs=1, type=click.INT,
+              help="How severe is this policy when violated. Range from 0 to 7 included.")
 @click.option('--notenabled', is_flag=True, help=" If the policy should not be considered")
 @click.option('--notification', nargs=1, multiple=True, help="Notification channel id to subscribe to the policy.")
 @click.pass_obj
@@ -349,7 +398,8 @@ def delete(cnf, policies):
 
 @policy.command(name='get-falco', short_help="Get a falco rules file")
 @click.argument('outfile', type=click.File('w'), default=sys.stdout)
-@click.option('--default', is_flag=True, help="Get the default falco rules file. (if not set the custom falco rules will be displayed)")
+@click.option('--default', is_flag=True,
+              help="Get the default falco rules file. (if not set the custom falco rules will be displayed)")
 @click.pass_obj
 def get_falco(cnf, outfile, default):
     """
@@ -376,7 +426,8 @@ def get_falco(cnf, outfile, default):
 
 @policy.command(name='set-falco', short_help="Set a falco rules file")
 @click.argument('falcofile', type=click.File('r'), default=sys.stdin)
-@click.option('--default', is_flag=True, help="Set the default falco rules file. (if not set the custom falco rules will be setted)")
+@click.option('--default', is_flag=True,
+              help="Set the default falco rules file. (if not set the custom falco rules will be setted)")
 @click.pass_obj
 def set_falco(cnf, falcofile, default):
     """
@@ -446,4 +497,4 @@ def _print_events(events):
 
 
 def _timestamp2datetime(timestamp):
-    return datetime.utcfromtimestamp(timestamp / 10**6)
+    return datetime.utcfromtimestamp(timestamp / 10 ** 6)
