@@ -63,8 +63,20 @@ def alerts(file_data, monitor: SdMonitorClient):
         return False, res
     existing_alerts = {alert['name']: alert for alert in res['alerts']}
 
+    ok, res = monitor.list_notification_channels()
+    if not ok:
+        return False, res
+    existing_notification_channels = {nc['name']: nc['id'] for nc in res['notificationChannels']}
+
     for i, alert in enumerate(file_data, start=1):
         name = alert['name']
+        alert['notificationChannelIds'] = []
+        for nc in alert['notificationChannelNames']:
+            if nc in existing_notification_channels:
+                alert['notificationChannelIds'].append(existing_notification_channels[nc])
+            else:
+                print(f"  Warning: The Notification Channel '{nc}' does not exist in the environment, "
+                      f"the restored alert won't be assigned to this NC.")
         print(f"[{i}/{total}] Creating alert {name}... ")
         if name in existing_alerts:
             if same_dict(alert, existing_alerts[name],
@@ -220,7 +232,7 @@ def _add_falco_list(self, name, items, append=False):
         "append": append,
     }
     res = self.http.post(self.url + '/api/secure/falco/lists', data=json.dumps(flist), headers=self.hdrs,
-                        verify=self.ssl_verify)
+                         verify=self.ssl_verify)
     return self._request_result(res)
 
 
